[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- nbxmpp: This is a fork of the xmpppy jabber python library. Most of the code is inherited but has been extended by implementation of non-blocking transports and new features like BOSH.
  - nbxmpp.auth_nb: Provides plugs for SASL and NON-SASL authentication mechanisms. Can be used both for client and transport authentication
  - nbxmpp.bosh
  - nbxmpp.c14n: XML canonicalisation methods (for XEP-0116)
  - nbxmpp.client_nb: Client class establishs connection to XMPP Server and handles authentication
  - nbxmpp.dispatcher_nb: Main xmpp decision making logic. Provides library with methods to assign different handlers to different XMPP stanzas and namespaces
  - nbxmpp.features_nb: Different stuff that wasn't worth separating it into modules (Registration, Privacy Lists, ...)
  - nbxmpp.idlequeue: Idlequeues are Gajim's network heartbeat. Transports can be plugged as idle objects and be informed about possible IO
  - nbxmpp.plugin: Provides PlugIn class functionality to develop extentions for xmpppy
  - nbxmpp.protocol: Protocol module contains tools that are needed for processing of xmpp-related data structures, including jabber-objects like JID or different stanzas and sub- stanzas) handling routines
  - nbxmpp.proxy_connectors: Module containing classes for proxy connecting. So far its HTTP CONNECT and SOCKS5 proxy
  - nbxmpp.roster_nb: Simple roster implementation. Can be used though for different tasks like mass-renaming of contacts.
  - nbxmpp.simplexml: Simplexml module provides xmpppy library with all needed tools to handle XML nodes and XML streams. I'm personally using it in many other separate projects. It is designed to be as standalone as possible
  - nbxmpp.smacks
  - nbxmpp.stringprepare
  - nbxmpp.tls_nb
  - nbxmpp.transports_nb: Transports are objects responsible for connecting to XMPP server and putting data to wrapped sockets in in desired form (SSL, TLS, TCP, for HTTP proxy, for SOCKS5 proxy...)